arsenal.maths.combinatorics package
===================================

Submodules
----------

arsenal.maths.combinatorics.alignments module
---------------------------------------------

.. automodule:: arsenal.maths.combinatorics.alignments
   :members:
   :undoc-members:
   :show-inheritance:

arsenal.maths.combinatorics.basics module
-----------------------------------------

.. automodule:: arsenal.maths.combinatorics.basics
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: arsenal.maths.combinatorics
   :members:
   :undoc-members:
   :show-inheritance:
